// importing necessary modules I used for this graph.
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';


sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.percentage))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);

// declaring constants by reading svg tag from index.html
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Start building pie graph
const render = (data,total) => {
  const pieData = pie().value(d=>d.percentage)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "Maroon",
      "pink",
      "green",
      "cyan",
      "yellow",
      "#014140"
    ]);
  // plotting the segments
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(140)
  	.padAngle(0)
  	.padRadius(0);
  // linking the data for each section of the segments
  const sections = svg.append("g")
  	.attr("transform", `translate(200,180)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.name));
  //linking data from the csv for displaying legends
  const legends = svg.append("g")
  	.attr("transform", "translate(500,70)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.name));
  // appending labels as text for legends
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.name);
  // appending labels as text for legends
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.percentage))+"%");
}


const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.percentage = +d.percentage;
    total += d.percentage
  });
  console.log(data)
	render(data,total);
};
run();